@@ -1,12 +1,16 @@
 from django.test import TestCase
-from wagtail.tests.utils import WagtailTestUtils
+from wagtail import VERSION as WAGTAIL_VERSION
 
 from tests.testapp.factories import PageWithColorFieldPageFactory
-from tests.testapp.models import PageWithColorField
 from wagtail_color_panel.edit_handlers import NativeColorPanel
 from wagtail_color_panel.widgets import ColorInputWidget
 
-# from wagtail.admin.edit_handlers import get_form_for_model
+if WAGTAIL_VERSION >= (3, 0):
+    from wagtail.test.utils import WagtailTestUtils
+else:
+    from wagtail.tests.utils import WagtailTestUtils
+
+# from wagtail.admin.panels import get_form_for_model
 # from wagtail.admin.forms import WagtailAdminModelForm, WagtailAdminPageForm
 
 
